@@ -1,4 +1,4 @@
 #' Returns the base url of the nbp api.
 nbp_api_base_url <- function() {
-    "http://api.nbp.pl/api/"
+    "https://api.nbp.pl/api/"
 }
